# pruebaEmer

pruebaEmer es una libreria de prueba.

## Instalación

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pruebaEmer.

```bash
pip install pruebaEmer

## Usage

```python
from pruebaEmer import *

# Funcion
a = pruebaEmer1()

## Contribuciones

No son necesarias.
